import Vue from 'vue'
import Cookies from 'js-cookie'
import 'normalize.css/normalize.css' // a modern alternative to CSS resets
import Element from 'element-ui'
import './styles/element-variables.scss'
import enLang from 'element-ui/lib/locale/lang/en'// 如果使用中文语言包请默认支持，无需额外引入，请删除该依赖
import '@/styles/index.scss' // global css
import App from './App'
import store from './store'
import router from './router'
import './icons' // icon
import './permission' // permission control
import './utils/error-log' // error log
import * as filters from './filters' // global filters
import './styles/fontawesome/css/all.min.css'
import './styles/fontawesome/css/fontawesome.css'
import './styles/fontawesome/css/brands.css'
import './styles/fontawesome/css/solid.css'
import './styles/styles.css'
import './styles/shared_table.css'
import './styles/form_styles.css'
import './styles/sales_analysis.css'
import './styles/disc_table.css'
import './styles/email_pat_set.css'
import './styles/inv_views.css'
import './styles/log_in.css'
import './styles/preview_table.css'
import './styles/access/access_common.css'
import './styles/access/accounts.css'
import './styles/access/error_record.css'
import './styles/inbound_inv_mgmt/inbound_inv_common.css'
import './styles/turnkey/turnkey_common.css'
// 下面是pdf指定id js
// import './styles/access/js/disc_your_script.js'
// import './styles/access/js/inv_your_script.js'
// import './styles/access/js/tw-city-selector.js'
// import './styles/access/js/your_script.js'
// 下面是pdf生成文件庫js
// import './styles/access/js/libs/FileSaver.min.js'

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online ! ! !
 */
if (process.env.NODE_ENV === 'production') {
  const { mockXHR } = require('../mock')
  mockXHR()
}

Vue.use(Element, {
  size: Cookies.get('size') || 'medium', // set element-ui default size
  locale: enLang // 如果使用中文，无需设置，请删除
})

// register global utility filters
Object.keys(filters).forEach(key => {
  Vue.filter(key, filters[key])
})

Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})

// 引入 Bootstrap CSS
const linkElement = document.createElement('link')
linkElement.rel = 'stylesheet'
linkElement.href = 'https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css'
linkElement.integrity = 'sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3'
linkElement.crossOrigin = 'anonymous'
document.head.appendChild(linkElement)

// 引入 Bootstrap JS
const scriptElement = document.createElement('script')
scriptElement.src = 'https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js'
scriptElement.integrity = 'sha384-ka7Sk0Gln4gmtz2MlQnikT1wXgYsOg+OMhuP+IlRH9sENBO0LRn5q+8nbTov4+1p'
scriptElement.crossOrigin = 'anonymous'
document.body.appendChild(scriptElement)

const BASE_URL_LOCAL = 'http://localhost:9528';
const BASE_URL_PROD = 'https://dev.aibooksbank.com';

const BASE_URL = window.location.hostname === 'localhost' ? BASE_URL_LOCAL : BASE_URL_PROD;
console.log(BASE_URL)
// 然后，您可以将 BASE_URL 导出，或者设置到 Vue 的原型上，使其在所有组件中可用
export { BASE_URL };


// 引入 popper JS
// const scriptElement = document.createElement('script')
// scriptElement.src = 'https://cdn.jsdelivr.net/npm/@popperjs/core@2.10.1/dist/umd/popper.min.js'
// scriptElement.integrity = 'sha384-7+zCNj/IqJ95wo16oMtfsKbZ9ccEh31eOz1HGyDuCQ6wgnyJNSYdrPa03rtR1zdB'
// scriptElement.crossOrigin = 'anonymous'
// document.body.appendChild(scriptElement)

// 引入 html2pdf 生成pdf JS
// const scriptElement = document.createElement('script')
// scriptElement.src = 'https://cdnjs.cloudflare.com/ajax/libs/html2pdf.js/0.10.1/html2pdf.bundle.js'
// document.body.appendChild(scriptElement)

