import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* 布局 */
import Layout from '@/layout'

/* 路由模块 */
import componentsRouter from './modules/components'
import chartsRouter from './modules/charts'
import tableRouter from './modules/table'
import nestedRouter from './modules/nested'

export const constantRoutes = [
    {
        path: '/redirect',
        component: Layout,
        hidden: true,
        children: [
            {
                path: '/redirect/:path(.*)',
                component: () => import('@/views/redirect/index')
            }
        ],
        meta: {
            title: '',
            icon: '',
            roles: ['admin', 'editor', 'admin22'] // 確保 'admin22' 也在這裡
        },
    },
    {
        path: '/login',
        component: () => import('@/views/login/index'),
        hidden: true,
        meta: {
            title: '',
            icon: '',
            roles: ['admin', 'editor', 'admin22'] // 確保 'admin22' 也在這裡
        },
    },
    {
        path: '/',
        redirect: '/home',
        hidden: true,
        meta: {
            title: '0.首頁',
            icon: 'dashboard',
            roles: ['admin', 'editor', 'admin22'] // 確保 'admin22' 也在這裡
        },
    },
    {
        path: '/home',
        component: Layout, // 使用 Layout 組件作為布局
        name: '首頁',
        meta: {
            title: '0.首頁',
            icon: 'dashboard',
            roles: ['admin', 'editor', 'admin22'] // 確保 'admin22' 也在這裡
        },
        children: [
            {
                path: '', // 空路徑表示這是 /home 的默認子路由
                name: 'Home',
                component: () => import('@/views/home/home.vue'), // 懶加載 Home 組件
                meta: {title: '首頁', icon: 'dashboard'}
            }
        ]
    },
]

export const asyncRoutes = [
    {
        path: '/system',
        component: Layout,
        alwaysShow: true,
        redirect: '/system/company',
        name: '資料管理',
        meta: {
            title: '1.資料管理',
            icon: 'list-check-solid',
            roles: ['admin', 'editor', 'admin22']
        },
        children: [
            {
                path: 'company',
                component: () => import('@/views/system/Company'),
                name: 'company',
                meta: {title: '1-1.企業資料及發票抬頭', roles: ['admin', 'editor']}
            },
            {
                path: 'email_pat_set',
                component: () => import('@/views/email_pat/EmailPatSet.vue'),
                name: 'email_pat_set',
                meta: {title: '1-2.Email版型設定', roles: ['admin', 'editor']}
            },
            {
                path: 'branch-management',
                component: () => import('@/views/system/BranchManagement.vue'),
                name: 'branch-management',
                meta: {title: '1-3.分支機構管理', roles: ['admin', 'editor']}
            },
            {
                path: 'branch-management-allocation',
                component: () =>
                    import('@/views/system/BranchManagementAllocation.vue'),
                name: 'branch-management-allocation',
                meta: {title: '1-4.分支機構配號檔案管理', roles: ['admin', 'editor']}
            },
            {
                path: 'invoice_prize',
                component: () => import('@/views/invoice_prize/InvoicePrize.vue'),
                name: 'invoice_prize',
                meta: {title: '1-5.統一發票對獎', roles: ['admin', 'editor']}
            },
            {
                path: 'winning_mgmt',
                component: () => import('@/views/invoice_prize/WinningMgmt.vue'),
                name: 'winning_mgmt',
                meta: {title: '1-6.中獎發票管理', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/product',
        component: Layout,
        alwaysShow: true,
        redirect: '/product/product-category',
        name: '產品管理',
        meta: {
            title: '2.產品管理',
            icon: 'product-hunt',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'product-category',
                component: () => import('@/views/product/ProductCategory.vue'),
                name: 'productCategory',
                meta: {title: '2-1.產品種類設定', roles: ['admin', 'editor']}
            },
            {
                path: 'product-unit',
                component: () => import('@/views/product/ProductUnit.vue'),
                name: 'productUnit',
                meta: {title: '2-2.產品單位設定', roles: ['admin', 'editor']}
            },
            {
                path: 'product-name',
                component: () => import('@/views/product/ProductName.vue'),
                name: 'productName',
                meta: {title: '2-3.產品品名設定', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/client',
        component: Layout,
        alwaysShow: true,
        redirect: '/client/client',
        name: '客戶管理',
        meta: {
            title: '3.客戶管理',
            icon: 'circle-user-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'client',
                component: () => import('@/views/client/Client.vue'),
                name: 'client',
                meta: {title: '3-1.客戶基本資料設定', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/invoice',
        component: Layout,
        alwaysShow: true,
        redirect: '/invoice/invoice-number',
        name: '自動取號管理',
        meta: {
            title: '4.自動取號管理',
            icon: 'qrcode-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'invoice-number',
                component: () => import('@/views/invoice/InvoiceNumber.vue'),
                name: 'invoiceNumber',
                meta: {title: '4-1.發票號碼管理', roles: ['admin', 'editor']}
            },
            {
                path: 'invoice-tax-category',
                component: () => import('@/views/invoice/InvoiceTaxCategory.vue'),
                name: 'InvoiceTaxCategorySetting',
                meta: {title: '4-2.發票稅別設定', roles: ['admin', 'editor']}
            },
            {
                path: 'unused-invoice-prefixes',
                component: () => import('@/views/invoice/UnusedInvoicePrefixes.vue'),
                name: 'DeclarationOfUnusedInvoicePrefixes',
                meta: {title: '4-3.空白未使用字軌檔申報', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/billing-inv-issuance-mgmt',
        component: Layout,
        alwaysShow: true,
        redirect: '/billing-inv-issuance-mgmt/billing-inv-issuance',
        name: '銷項發票開立管理',
        meta: {
            title: '5.銷項發票開立管理',
            icon: 'money-check-dollar-solid',
            roles: ['admin', 'editor']
        },
        children: [
            // {
            //     path: 'billing-inv-issuance-old',
            //     component: () => import('@/views/billingInvIssuanceMgmt/BillingInvIssuanceOld.vue'),
            //     name: 'BillingInvIssuance',
            //     meta: {title: '5-1.銷項發票開立/請款作業old', roles: ['admin', 'editor']}
            // },
            {
                path: 'billing-inv-issuance',
                component: () => import('@/views/billingInvIssuanceMgmt/BillingInvIssuance.vue'),
                name: 'BillingInvIssuance',
                meta: {title: '5-1.銷項發票開立/請款作業', roles: ['admin', 'editor']}
            },
            {
                path: 'b2b-sales-details',
                component: () => import('@/views/billingInvIssuanceMgmt/B2BSalesDetails.vue'),
                name: 'B2BSalesDetails',
                meta: {title: '5-2.B2B銷項開立明細查詢', roles: ['admin', 'editor']}
            },
            {
                path: 'b2c-sales-details',
                component: () => import('@/views/billingInvIssuanceMgmt/B2CSalesDetails.vue'),
                name: 'B2CSalesDetails',
                meta: {title: '5-3.B2C銷項開立明細查詢', roles: ['admin', 'editor']}
            },
        ]
    },
    {
        path: '/allowance-return-void',
        component: Layout,
        alwaysShow: true,
        redirect: '/allowance-return-void/allowance-void',
        name: '銷項折讓/作廢管理',
        meta: {
            title: '6.銷項發票退折/作廢管理',
            icon: 'file-invoice-solid',
            roles: ['admin', 'editor']
        },
        children: [
            // {
            //     path: 'allowance-void-old',
            //     component: () => import('@/views/allowanceReturnVoid/AllowanceVoidOld.vue'),
            //     name: 'AllowanceVoid',
            //     meta: {title: '6-1.銷項發票退折作業old', roles: ['admin', 'editor']}
            // },
            {
                path: 'allowance-void',
                component: () => import('@/views/allowanceReturnVoid/AllowanceVoid.vue'),
                name: 'AllowanceVoid',
                meta: {title: '6-1.銷項發票退折作業', roles: ['admin', 'editor']}
            },
            {
                path: 'invoice-allowance-details',
                component: () => import('@/views/allowanceReturnVoid/InvoiceAllowanceDetails.vue'),
                name: 'InvoiceAllowanceDetails',
                meta: {title: '6-2.銷項發票退折明細查詢', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/input-invoice',
        component: Layout,
        alwaysShow: true,
        redirect: '/input-invoice/input-invoice-mgmt',
        name: '進項發票接收管理',
        meta: {
            title: '7.進項發票接收管理',
            icon: 'file-invoice-solid',
            roles: ['admin', 'editor']
        },
        children: [
            // {
            //     path: 'input-invoice-mgmt-old',
            //     component: () => import('@/views/inputInvoice/InputInvoiceMgmtOld.vue'),
            //     name: 'InputInvoiceMgmt',
            //     meta: {title: '7-1.進項發票接收作業old', roles: ['admin', 'editor']}
            // },
            {
                path: 'input-invoice-mgmt',
                component: () => import('@/views/inputInvoice/InputInvoiceMgmt.vue'),
                name: 'InputInvoiceMgmt',
                meta: {title: '7-1.進項發票接收作業', roles: ['admin', 'editor']}
            },
            {
                path: 'input-invoice-details',
                component: () => import('@/views/inputInvoice/B2BInputInvoiceDetails.vue'),
                name: 'InputInvoiceMgmt',
                meta: {title: '7-2.B2B進項發票明細查詢', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/input-invoice-allowance-void',
        component: Layout,
        alwaysShow: true,
        redirect: '/input-invoice-allowance-void/input-invoice-allowance-void-mgmt',
        name: '進項發票退折/作廢管理',
        meta: {
            title: '8.進項發票退折/作廢管理',
            icon: 'file-invoice-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'input-invoice-allowance-void-mgmt',
                component: () => import('@/views/inputInvoiceAllowanceVoid/InputInvoiceAllowanceVoidMgmt.vue'),
                name: 'InputInvoiceAllowanceVoidMgmt',
                meta: {title: '8-1.進項發票退折作業', roles: ['admin', 'editor']}
            },
            {
                path: 'input-invoice-allowance-void-details',
                component: () => import('@/views/inputInvoiceAllowanceVoid/InputInvoiceAllowanceVoidDetails.vue'),
                name: 'InputInvoiceAllowanceVoidDetails',
                meta: {title: '8-2.進項發票退折明細查詢', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/sales-analysis',
        component: Layout,
        alwaysShow: true,
        redirect: '/sales-analysis/customer-analysis',
        name: '銷售分析圖',
        meta: {
            title: '9.銷售分析圖',
            icon: 'signal-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'customer-analysis',
                component: () => import('@/views/salesAnalysis/CustomerAnalysis.vue'),
                name: 'CustomerAnalysis',
                meta: {title: '9-1.客戶分析', roles: ['admin', 'editor']}
            },
            // {
            //     path: 'Revenue-Analysis',
            //     component: () => import('@/views/salesAnalysis/RevenueAnalysis.vue'),
            //     name: 'RevenueAnalysis',
            //     meta: {title: '9-1.營收分析', roles: ['admin', 'editor']}
            // },
            // {
            //     path: 'product-analysis',
            //     component: () => import('@/views/salesAnalysis/ProductAnalysis.vue'),
            //     name: 'ProductAnalysis',
            //     meta: {title: '9-2.產品分析', roles: ['admin', 'editor']}
            // },
            // {
            //     path: 'buyer-sales',
            //     component: () => import('@/views/salesAnalysis/BuyerSales.vue'),
            //     name: 'BuyerSales',
            //     meta: {title: '9-3.客戶分析', roles: ['admin', 'editor']}
            // }
        ]
    },
    {
        path: '/turnkey',
        component: Layout,
        alwaysShow: true,
        redirect: '/turnkey/abnormal-message-log',
        name: 'Turnkey',
        meta: {
            title: '10.Turnkey',
            icon: 'key-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'abnormal-message-log',
                component: () => import('@/views/turnkey/AbnormalMessageLog.vue'),
                name: 'AbnormalMessageLog',
                meta: {title: '10-1.異常訊息紀錄', roles: ['admin', 'editor']}
            },
            {
                path: 'daily-system-check',
                component: () => import('@/views/turnkey/DailySystemCheck.vue'),
                name: 'DailySystemCheck',
                meta: {title: '10-2.每日系統檢核', roles: ['admin', 'editor']}
            },
            {
                path: 'turnkey-summary-result',
                component: () => import('@/views/turnkey/TurnkeySummaryResult.vue'),
                name: 'TurnkeySummaryResult',
                meta: {title: '10-3.Turnkey摘要結果', roles: ['admin', 'editor']}
            },
            {
                path: 'event-log',
                component: () => import('@/views/turnkey/EventLog.vue'),
                name: 'EventLog',
                meta: {title: '10-4.事件紀錄', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/permission-management',
        component: Layout,
        alwaysShow: true,
        redirect: '/permission-management/system-issue-catalog',
        name: '權限管理',
        meta: {
            title: '11.權限管理',
            icon: 'cog-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'system-role-module-setting',
                component: () => import('@/views/permissionManagement/SystemRoleModuleSetting.vue'),
                name: 'SystemRoleModuleSetting',
                meta: {title: '11-1.系統角色模組設定', roles: ['admin', 'editor']}
            },
            {
                path: 'user-management',
                component: () => import('@/views/permissionManagement/UserManagement.vue'),
                name: 'UserManagement',
                meta: {title: '11-2.使用者管理', roles: ['admin', 'editor']}
            },
            {
                path: 'invitation-setting',
                component: () => import('@/views/permissionManagement/InvitationSetting.vue'),
                name: 'InvitationSetting',
                meta: {title: '11-3.邀請設定', roles: ['admin', 'editor']}
            },
            {
                path: 'system-login-logout-log?selflog=0',
                component: () => import('@/views/permissionManagement/SystemLoginLogoutLog.vue'),
                name: 'SystemLoginLogoutLog',
                meta: {title: '11-4.系統登出入日誌', roles: ['admin', 'editor']}
            },
            {
                path: 'error-message-log',
                component: () => import('@/views/permissionManagement/ErrorMessageLog.vue'),
                name: 'ErrorMessageLog',
                meta: {title: '11-5.錯誤訊息紀錄', roles: ['admin', 'editor']}
            }
        ]
    }
];


const createRouter = () =>
    new Router({
        scrollBehavior: () => ({y: 0}),
        routes: constantRoutes
    })

const router = createRouter()

router.beforeEach((to, from, next) => {
    // 手機裝置判斷
    const isMobile = window.innerWidth < 768

    // 如果是手機版並且當前路徑不是手機版應該導向的頁面
    if (isMobile && to.path === '/home') {
        // 重定向到指定的銷項發票開立管理頁面
        next('/billing-inv-issuance-mgmt/billing-inv-issuance')
    } else {
        next() // 否則繼續導航
    }
})

export function resetRouter() {
    const newRouter = createRouter()
    router.matcher = newRouter.matcher
}

export default router

export const asyncRouterMap = [
    {
        path: '/system',
        component: Layout,
        alwaysShow: true,
        redirect: '/system/company',
        name: '資料管理',
        meta: {
            title: '1.資料管理',
            icon: 'list-check-solid',
            roles: ['admin', 'editor', 'admin22']
        },
        children: [
            {
                path: 'company',
                component: () => import('@/views/system/Company'),
                name: 'company',
                meta: {title: '1-1.企業資料及發票抬頭', roles: ['admin', 'editor']}
            },
            {
                path: 'email_pat_set',
                component: () => import('@/views/email_pat/EmailPatSet.vue'),
                name: 'email_pat_set',
                meta: {title: '1-2.Email版型設定', roles: ['admin', 'editor']}
            },
            {
                path: 'branch-management',
                component: () => import('@/views/system/BranchManagement.vue'),
                name: 'branch-management',
                meta: {title: '1-3.分支機構管理', roles: ['admin', 'editor']}
            },
            {
                path: 'branch-management-allocation',
                component: () =>
                    import('@/views/system/BranchManagementAllocation.vue'),
                name: 'branch-management-allocation',
                meta: {title: '1-4.分支機構配號管理', roles: ['admin', 'editor']}
            }
            // {
            //     path: 'invoice_prize',
            //     component: () => import('@/views/invoice_prize/InvoicePrize.vue'),
            //     name: 'invoice_prize',
            //     meta: {title: '1-5 中獎號碼匯入', roles: ['admin', 'editor']}
            // },
            // {
            //     path: 'winning_mgmt',
            //     component: () => import('@/views/invoice_prize/WinningMgmt.vue'),
            //     name: 'winning_mgmt',
            //     meta: {title: '1-6 中獎發票明細', roles: ['admin', 'editor']}
            // }
        ]
    },
    {
        path: '/product',
        component: Layout,
        alwaysShow: true,
        redirect: '/product/product-category',
        name: '產品管理',
        meta: {
            title: '2.產品管理',
            icon: 'product-hunt',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'product-category',
                component: () => import('@/views/product/ProductCategory.vue'),
                name: 'productCategory',
                meta: {title: '2-1.產品種類設定', roles: ['admin', 'editor']}
            },
            {
                path: 'product-unit',
                component: () => import('@/views/product/ProductUnit.vue'),
                name: 'productUnit',
                meta: {title: '2-2.產品單位設定', roles: ['admin', 'editor']}
            },
            {
                path: 'product-name',
                component: () => import('@/views/product/ProductName.vue'),
                name: 'productName',
                meta: {title: '2-3.產品品名設定', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/client',
        component: Layout,
        alwaysShow: true,
        redirect: '/client/client',
        name: '客戶管理',
        meta: {
            title: '3.客戶管理',
            icon: 'circle-user-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'client',
                component: () => import('@/views/client/Client.vue'),
                name: 'client',
                meta: {title: '3-1.客戶基本資料設定', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/invoice',
        component: Layout,
        alwaysShow: true,
        redirect: '/invoice/invoice-number',
        name: '自動取號管理',
        meta: {
            title: '4.自動取號管理',
            icon: 'qrcode-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'invoice-number',
                component: () => import('@/views/invoice/InvoiceNumber.vue'),
                name: 'invoiceNumber',
                meta: {title: '4-1.發票號碼管理', roles: ['admin', 'editor']}
            },
            {
                path: 'invoice-tax-category',
                component: () => import('@/views/invoice/InvoiceTaxCategory.vue'),
                name: 'InvoiceTaxCategorySetting',
                meta: {title: '4-2.發票稅別設定', roles: ['admin', 'editor']}
            },
            {
                path: 'unused-invoice-prefixes',
                component: () => import('@/views/invoice/UnusedInvoicePrefixes.vue'),
                name: 'DeclarationOfUnusedInvoicePrefixes',
                meta: {title: '4-3.空白字軌檔申報', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/billing-inv-issuance-mgmt',
        component: Layout,
        alwaysShow: true,
        redirect: '/billing-inv-issuance-mgmt/billing-inv-issuance',
        name: '銷項發票開立管理',
        meta: {
            title: '5.銷項發票管理',
            icon: 'money-check-dollar-solid',
            roles: ['admin', 'editor']
        },
        children: [
            // {
            //     path: 'billing-inv-issuance-old',
            //     component: () => import('@/views/billingInvIssuanceMgmt/BillingInvIssuanceOld.vue'),
            //     name: 'BillingInvIssuance',
            //     meta: {title: '5-1.銷項發票開立/請款作業old', roles: ['admin', 'editor']}
            // },
            {
                path: 'billing-inv-issuance',
                component: () => import('@/views/billingInvIssuanceMgmt/BillingInvIssuance.vue'),
                name: 'BillingInvIssuance',
                meta: {title: '5-1.銷項發票開立管理', roles: ['admin', 'editor']}
            },
            {
                path: 'b2b-sales-details',
                component: () => import('@/views/billingInvIssuanceMgmt/B2BSalesDetails.vue'),
                name: 'B2BSalesDetails',
                meta: {title: '5-2.B2B銷項開立明細', roles: ['admin', 'editor']}
            },
            {
                path: 'b2c-sales-details',
                component: () => import('@/views/billingInvIssuanceMgmt/B2CSalesDetails.vue'),
                name: 'B2CSalesDetails',
                meta: {title: '5-3.B2C銷項開立明細', roles: ['admin', 'editor']}
            },
        ]
    },
    {
        path: '/allowance-return-void',
        component: Layout,
        alwaysShow: true,
        redirect: '/allowance-return-void/allowance-void',
        name: '銷項折讓/作廢管理',
        meta: {
            title: '6.銷項退折管理',
            icon: 'file-invoice-solid',
            roles: ['admin', 'editor']
        },
        children: [
            // {
            //     path: 'allowance-void-old',
            //     component: () => import('@/views/allowanceReturnVoid/AllowanceVoidOld.vue'),
            //     name: 'AllowanceVoid',
            //     meta: {title: '6-1.銷項發票退折作業old', roles: ['admin', 'editor']}
            // },
            {
                path: 'allowance-void',
                component: () => import('@/views/allowanceReturnVoid/AllowanceVoid.vue'),
                name: 'AllowanceVoid',
                meta: {title: '6-1.銷項發票退折查詢', roles: ['admin', 'editor']}
            }
            // {
            //     path: 'invoice-allowance-details',
            //     component: () => import('@/views/allowanceReturnVoid/InvoiceAllowanceDetails.vue'),
            //     name: 'InvoiceAllowanceDetails',
            //     meta: {title: '6-2.銷項發票退折明細', roles: ['admin', 'editor']}
            // }
        ]
    },
    {
        path: '/input-invoice',
        component: Layout,
        alwaysShow: true,
        redirect: '/input-invoice/input-invoice-mgmt',
        name: '進項發票接收管理',
        meta: {
            title: '7.進項接收管理',
            icon: 'file-invoice-solid',
            roles: ['admin', 'editor']
        },
        children: [
            // {
            //     path: 'input-invoice-mgmt-old',
            //     component: () => import('@/views/inputInvoice/InputInvoiceMgmtOld.vue'),
            //     name: 'InputInvoiceMgmt',
            //     meta: {title: '7-1.進項發票接收作業old', roles: ['admin', 'editor']}
            // },
            {
                path: 'input-invoice-mgmt',
                component: () => import('@/views/inputInvoice/InputInvoiceMgmt.vue'),
                name: 'InputInvoiceMgmt',
                meta: {title: '7-1.進項發票接收作業', roles: ['admin', 'editor']}
            },
            {
                path: 'input-invoice-details',
                component: () => import('@/views/inputInvoice/B2BInputInvoiceDetails.vue'),
                name: 'InputInvoiceMgmt',
                meta: {title: '7-2.B2B進項發票明細', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/input-invoice-allowance-void',
        component: Layout,
        alwaysShow: true,
        redirect: '/input-invoice-allowance-void/input-invoice-allowance-void-mgmt',
        name: '進項發票退折/作廢管理',
        meta: {
            title: '8.進項退折管理',
            icon: 'file-invoice-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'input-invoice-allowance-void-mgmt',
                component: () => import('@/views/inputInvoiceAllowanceVoid/InputInvoiceAllowanceVoidMgmt.vue'),
                name: 'InputInvoiceAllowanceVoidMgmt',
                meta: {title: '8-1.進項發票退折作業', roles: ['admin', 'editor']}
            },
            {
                path: 'input-invoice-allowance-void-details',
                component: () => import('@/views/inputInvoiceAllowanceVoid/InputInvoiceAllowanceVoidDetails.vue'),
                name: 'InputInvoiceAllowanceVoidDetails',
                meta: {title: '8-2.進項發票退折明細', roles: ['admin', 'editor']}
            }
        ]
    },
    {
        path: '/sales-analysis',
        component: Layout,
        alwaysShow: true,
        redirect: '/sales-analysis/customer-analysis',
        name: '銷售分析圖',
        meta: {
            title: '9.銷售分析圖',
            icon: 'signal-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'customer-analysis',
                component: () => import('@/views/salesAnalysis/CustomerAnalysis.vue'),
                name: 'CustomerAnalysis',
                meta: {title: '9-1.客戶分析', roles: ['admin', 'editor']}
            },
            // {
            //     path: 'revenue-analysis',
            //     component: () => import('@/views/salesAnalysis/RevenueAnalysis.vue'),
            //     name: 'RevenueAnalysis',
            //     meta: {title: '9-1.營收分析', roles: ['admin', 'editor']}
            // },
            // {
            //     path: 'product-analysis',
            //     component: () => import('@/views/salesAnalysis/ProductAnalysis.vue'),
            //     name: 'ProductAnalysis',
            //     meta: {title: '9-2.產品分析', roles: ['admin', 'editor']}
            // },
            // {
            //     path: 'buyer-sales',
            //     component: () => import('@/views/salesAnalysis/BuyerSales.vue'),
            //     name: 'BuyerSales',
            //     meta: {title: '9-3.客戶分析', roles: ['admin', 'editor']}
            // }
        ]
    },
    {
        path: '/permission-management',
        component: Layout,
        alwaysShow: true,
        redirect: '/permission-management/system-issue-catalog',
        name: '權限管理',
        meta: {
            title: '10.權限管理',
            icon: 'cog-solid',
            roles: ['admin', 'editor']
        },
        children: [
            {
                path: 'system-role-module-setting',
                component: () => import('@/views/permissionManagement/SystemRoleModuleSetting.vue'),
                name: 'SystemRoleModuleSetting',
                meta: {title: '10-1.系統角色設定', roles: ['admin', 'editor']}
            },
            {
                path: 'user-management',
                component: () => import('@/views/permissionManagement/UserManagement.vue'),
                name: 'UserManagement',
                meta: {title: '10-2.使用者管理', roles: ['admin', 'editor']}
            },
            {
                path: 'invitation-setting',
                component: () => import('@/views/permissionManagement/InvitationSetting.vue'),
                name: 'InvitationSetting',
                meta: {title: '10-3.邀請設定', roles: ['admin', 'editor']}
            },
            {
                path: 'system-login-logout-log',
                component: () => import('@/views/permissionManagement/SystemLoginLogoutLog.vue'),
                name: 'SystemLoginLogoutLog',
                meta: {title: '10-4.系統登出入日誌', roles: ['admin', 'editor']}
            }
            // {
            //     path: 'error-message-log',
            //     component: () => import('@/views/permissionManagement/ErrorMessageLog.vue'),
            //     name: 'ErrorMessageLog',
            //     meta: {title: '10-5.錯誤訊息紀錄', roles: ['admin', 'editor']}
            // }
        ]
    }
];
