import axios from 'axios'

const token = {
  state: {
    seiToken: '',  // 初始化 seiToken 狀態
    jwtToken: ''  // 初始化 jwtToken 狀態
  },
  mutations: {
    SET_SEI_TOKEN: (state, seiToken) => {
      state.seiToken = seiToken  // 儲存獲取到的 seiToken
    },
    SET_JWT_TOKEN: (state, jwtToken) => {
      state.jwtToken = jwtToken  // 儲存獲取到的 jwtToken
    }
  },
  actions: {
    // 從 API 獲取 seiToken 和 jwtToken，如果 Vuex state 中沒有存儲則執行，否則直接使用存儲的 token
    FetchSeiToken({commit, state}) {
      return new Promise((resolve, reject) => {
        // 首先檢查 state 中是否已有 token
        if (state.seiToken && state.jwtToken) {
          // 如果已有 token，直接解析 Promise，不再請求新的 token
          resolve({seiToken: state.seiToken, jwtToken: state.jwtToken})
        } else if (window.location.hostname === 'localhost') {
          // 本地測試情況下的處理邏輯
          const mockSeiToken = 'mockTokenForLocalhost'
          commit('SET_SEI_TOKEN', mockSeiToken)
          resolve(mockSeiToken)
        } else {
          // 向 API 請求 seiToken
          axios.get(`${process.env.VUE_APP_API_DEV_URL}/sei/backend/php/page/getToken.php`).then(response => {
            const seiToken = response.data.seiToken
            commit('SET_SEI_TOKEN', seiToken)
            // 使用獲取到的 seiToken 進行登入
            axios.get(`${process.env.VUE_APP_API_BASE_URL}/api/login/${seiToken}`).then(loginResponse => {
              const jwtToken = loginResponse.data.token
              commit('SET_JWT_TOKEN', jwtToken)
              resolve({seiToken, jwtToken})
            }).catch(loginError => {
              window.location.href = `${process.env.VUE_APP_LOGIN_BASE}/nopwdlogin/logout?aiKey=e8d275af37ce2c474cbd3e65c0bce5c8&aiAp=sei&redirectUrl=${process.env.VUE_APP_LOGIN_URL}`;
            })
          }).catch(error => {
            window.location.href = `${process.env.VUE_APP_LOGIN_BASE}/nopwdlogin/logout?aiKey=e8d275af37ce2c474cbd3e65c0bce5c8&aiAp=sei&redirectUrl=${process.env.VUE_APP_LOGIN_URL}`;
          })
        }
      })
    }
  }
}

export default token
